extract

package
v0.0.0-...-9c968f8 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 10, 2026 License: Unlicense Imports: 12 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Extract

func Extract(src, dst string) (bool, error)

Extract extracts the archive at src into the dst directory. It detects the archive type by file extension. Returns true if the file was extracted, false if the format is not recognised.

Types

This section is empty.

Jump to